@@ -19,7 +19,7 @@
 
 extern bool timeRunning; //varibale declared in gui.cpp
 
-Info::Info(QWidget *parent): QPlainTextEdit(parent){
+Info::Info(QWidget *parent): QTextEdit(parent){
      setWindowFlags(Qt::WindowStaysOnTopHint | Qt::Window);
      setReadOnly(true);
      resize(500,450);
@@ -28,13 +28,13 @@ Info::Info(QWidget *parent): QPlainTextEdit(parent){
 
 Info::~Info(){ }
 
-void Info::showEvent(QShowEvent* show_pref){
+void Info::showEvent(QShowEvent* show_){
      starting();
-     QPlainTextEdit::showEvent(show_pref);
+     QTextEdit::showEvent(show_);
 }
 
 void Info::closeEvent(QCloseEvent* window_close){
      if(!timeRunning)
        finishing();
-     QPlainTextEdit::closeEvent(window_close);
+     QTextEdit::closeEvent(window_close);
 }
